@@ -3,16 +3,16 @@ use crate::{SyntaxNode, SyntaxToken};
 /// An element of a syntax tree.
 /// Either a node or a token.
 #[derive(Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
-pub enum SyntaxElement<K> {
+pub enum SyntaxElement<C> {
     #[allow(missing_docs)]
-    Node(SyntaxNode<K>),
+    Node(SyntaxNode<C>),
     #[allow(missing_docs)]
-    Token(SyntaxToken<K>),
+    Token(SyntaxToken<C>),
 }
 
-impl<K> SyntaxElement<K> {
+impl<C> SyntaxElement<C> {
     /// Asserts this element is a node. Panics if it was actually a token.
-    pub fn assert_node(self) -> SyntaxNode<K> {
+    pub fn assert_node(self) -> SyntaxNode<C> {
         match self {
             Self::Node(node) => node,
             Self::Token(_) => panic!("expected node"),
@@ -20,7 +20,7 @@ impl<K> SyntaxElement<K> {
     }
 
     /// Asserts this element is a token. Panics if it was actually a node.
-    pub fn assert_token(self) -> SyntaxToken<K> {
+    pub fn assert_token(self) -> SyntaxToken<C> {
         match self {
             Self::Node(_) => panic!("expected token"),
             Self::Token(token) => token,
